<?php

namespace Drupal\monarch_symlink;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the symlink entity type.
 */
class SymlinkAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view symlink');

      case 'update':
        return AccessResult::allowedIfHasPermissions($account, ['edit symlink', 'administer symlink'], 'OR');

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete symlink', 'administer symlink'], 'OR');

      default:
        // No opinion.
        return AccessResult::neutral();
    }

  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['create symlink', 'administer symlink'], 'OR');
  }

}
